ProjectionType
==============

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: ProjectionType
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ProjectionType.EQUIRECTANGULAR
      ~ProjectionType.HEALPIX
      ~ProjectionType.MERCATOR
      ~ProjectionType.PLOTTED
      ~ProjectionType.SKY_IMAGE
      ~ProjectionType.SPHERICAL
      ~ProjectionType.TAN
      ~ProjectionType.TOAST

   .. rubric:: Methods Summary

   .. autosummary::

      ~ProjectionType.from_text

   .. rubric:: Attributes Documentation

   .. autoattribute:: EQUIRECTANGULAR
   .. autoattribute:: HEALPIX
   .. autoattribute:: MERCATOR
   .. autoattribute:: PLOTTED
   .. autoattribute:: SKY_IMAGE
   .. autoattribute:: SPHERICAL
   .. autoattribute:: TAN
   .. autoattribute:: TOAST

   .. rubric:: Methods Documentation

   .. automethod:: from_text
